summaryrefslogtreecommitdiff
path: root/tests/guix-system.sh
diff options
context:
space:
mode:
authorAlex Kost <alezost@gmail.com>2016-01-27 15:45:01 +0300
committerAlex Kost <alezost@gmail.com>2016-01-29 20:21:53 +0300
commit0190c1c02fd8cefa9642add58b4c7ccf75f082a7 (patch)
treec25c9eb16b2d1bb6d242c073637811d16ae8d391 /tests/guix-system.sh
parentdd17bc38213d72a06d9a2a1e5402abcf24b0c21a (diff)
downloadgnu-guix-0190c1c02fd8cefa9642add58b4c7ccf75f082a7.tar
gnu-guix-0190c1c02fd8cefa9642add58b4c7ccf75f082a7.tar.gz
Rename (gnu services dmd) to (gnu services shepherd).
* gnu/services/dmd.scm: Rename to... * gnu/services/shepherd.scm: ... this. * gnu/system.scm: Use it. * gnu/system/install.scm: Likewise. * gnu/services/xorg.scm: Likewise. * gnu/services/web.scm: Likewise. * gnu/services/ssh.scm: Likewise. * gnu/services/networking.scm: Likewise. * gnu/services/mail.scm: Likewise. * gnu/services/lirc.scm: Likewise. * gnu/services/desktop.scm: Likewise. * gnu/services/dbus.scm: Likewise. * gnu/services/databases.scm: Likewise. * gnu/services/base.scm: Likewise. * gnu/services/avahi.scm: Likewise. * guix/scripts/system.scm: Likewise. * tests/services.scm: Likewise. * tests/guix-system.sh: Likewise. * doc/guix.texi (Shepherd Services): Adjust accordingly. * gnu-system.am (GNU_SYSTEM_MODULES): Likewise. * po/guix/POTFILES.in: Likewise.
Diffstat (limited to 'tests/guix-system.sh')
-rw-r--r--tests/guix-system.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/guix-system.sh b/tests/guix-system.sh
index 02e2524d9e..cd135b9a88 100644
--- a/tests/guix-system.sh
+++ b/tests/guix-system.sh
@@ -114,10 +114,10 @@ else
grep "service 'networking'.*more than once" "$errorfile"
fi
# Reporting unmet dmd requirements.
cat > "$tmpfile" <<EOF
-(use-modules (gnu) (gnu services dmd))
+(use-modules (gnu) (gnu services shepherd))
(use-service-modules networking)
(define buggy-service-type
@@ -114,10 +114,10 @@ else
grep "service 'networking'.*more than once" "$errorfile"
fi
-# Reporting unmet dmd requirements.
+# Reporting unmet shepherd requirements.
cat > "$tmpfile" <<EOF